# spec file for CERN ROOT 4.02.00 for Linux RedHat 
#
Summary: CERN ROOT 4.02.00  for Linux RedHat
Name: root
Version: 4.02.00
Release: 1
Copyright: ROOT Software Terms and Conditions (see package)
Group: Applications/data analysis system
Source0: root_v4.02.00.source.tar.gz
Source1: pythia5.tar.gz
Source2: pythia6.tar.gz
Source3: venus.tar.gz
URL: http://root.cern.ch
Distribution: Lynx BCC Company
Vendor: European Organization for Nuclear Research (CERN) ROOT team
Packager: Lynx BCC Company <http://www.lynx.ru>
Requires: cernlib >= 2003
BuildRoot: /tmp/%{name}-%{version}
Prefix: /usr

%description
The ROOT system provides a set of object-oriented  frameworks
with all the functionality needed to handle and analyse large amounts of
data in a very efficient way. 
Currently the emphasis of ROOT is on the data analysis domain but thanks 
to the approach of loosely coupled
object-oriented frameworks the system can easily be extended to other 
domains. 
ROOT is an open system that can be dynamically extended by linking 
external libraries. 
This makes ROOT a premier platform on which to build data acquisition, 
simulation and data analysis systems.
#

%prep

%setup -c 
export ROOT=$RPM_BUILD_ROOT
mkdir -p $ROOT/usr/lib/root
mkdir -p /usr/lib/root

#mkdir -p $ROOT/usr/share/root/
cd root/fonts
rm -rf *
cd ../..
mkdir pythia5
cd pythia5
gzip -dc /usr/src/redhat/SOURCES/pythia5.tar.gz | tar -xvvf -
cd ..
mkdir pythia6
cd pythia6
gzip -dc /usr/src/redhat/SOURCES/pythia6.tar.gz | tar -xvvf -
cd ..
mkdir venus
cd venus
gzip -dc /usr/src/redhat/SOURCES/venus.tar.gz | tar -xvvf - 

%build
export ROOT=$RPM_BUILD_ROOT
# create libPythia.so and libPythia6.so
cd pythia5
./makePythia.linux
cp libPythia.so /usr/lib/root
cp libPythia.so $ROOT/usr/lib/root
cd ..
cd pythia6
./makePythia6.linux
cp libPythia6.so /usr/lib/root
cp libPythia6.so $ROOT/usr/lib/root
cd ..
# create libVenus.so
cd venus 
make all
cp libVenus.so /usr/lib/root
cp libVenus.so $ROOT/usr/lib/root
cd ..
cd root
if ( ! printenv CERN > /dev/null )
  then
       CERN=/usr/cernlib
fi
if ( ! printenv CERN_LEVEL > /dev/null )
  then
       CERN_LEVEL=2004
fi

./configure linux \
 --prefix=/usr \
 --bindir=/usr/bin \
 --libdir=/usr/lib/root \
 --incdir=/usr/include/root \
 --etcdir=/etc/root \
 --fontdir=/usr/share/root/fonts \
 --mandir=/usr/share/man/man1 \
 --datadir=/usr/share/root \
 --macrodir=/usr/share/root/macros \
 --cintincdir=/usr/share/root/cint \
 --iconpath=/usr/share/root/icons \
 --docdir=%{_docdir}/%{name}-%{version} \
 --testdir=%{_docdir}/%{name}-%{version}/test \
 --tutdir=%{_docdir}/%{name}-%{version}/tutorials \
 --enable-soversion \
 --disable-srp \
 --disable-globus \
 --with-cern-libdir=$CERN/$CERN_LEVEL/lib \
 --with-pythia-libdir=/usr/lib/root \
 --with-pythia6-libdir=/usr/lib/root \
 --with-venus-libdir=/usr/lib/root

Text=`uname -r | sed 's/[^smp]*//' -`
if [ "x$Text" = "x" ] 
 then
   gmake 
 else
   gmake -j2
fi

%install
cd root
gmake install DESTDIR=${RPM_BUILD_ROOT}
chown -R root.root ${RPM_BUILD_ROOT}


%files
%attr (-,root,root)
%doc root/LICENSE root/README/* root/test/ root/tutorials/
/usr/bin/g2root
/usr/bin/g2rootold
/usr/bin/h2root
/usr/bin/cint
/usr/bin/hadd
/usr/bin/makecint
/usr/bin/memprobe
/usr/bin/proofd
/usr/bin/proofserv
/usr/bin/rmkdepend
/usr/bin/root
/usr/bin/rootcint
/usr/bin/root-config
/usr/bin/rootd
/usr/bin/root.exe
/usr/bin/rootn.exe
/usr/bin/ssh2rpd
/usr/bin/xrootd
/usr/lib/root
/usr/include/root
/etc/root
/usr/share/aclocal/root.m4
/usr/share/emacs/site-lisp/root-help.el
/usr/share/root
%docdir /usr/share/man/man1
/usr/share/man/man1/*

%clean
cd ..
#rm -f /usr/lib/root/libPythia.so
#rm -f /usr/lib/root/libPythia6.so
#rm -f /usr/lib/root/libVenus.so
rm -rf %{name}-%{version}
rm -rf $RPM_BUILD_ROOT
   
#  script to run after installing ROOT

%post
if grep "/usr/lib/root" /etc/ld.so.conf > \
  /dev/null
then 
   true
else
   echo "/usr/lib/root" >> /etc/ld.so.conf
   /sbin/ldconfig
fi

echo "-----------------------------------------------------------------"
echo ""
echo "ROOT 4.02.00 system  has been  installed in $RPM_INSTALL_PREFIX/bin      
"
echo ""
echo "-----------------------------------------------------------------"

#  script to run after uninstalling ROOT

%postun
if grep "/usr/lib/root" /etc/ld.so.conf > /dev/null
then 
    true
    grep -v "/usr/lib/root" /etc/ld.so.conf >\
    /etc/ld.so.conf.tmp
    mv -f /etc/ld.so.conf.tmp /etc/ld.so.conf
    /sbin/ldconfig
fi
